//****************************************************************************
// @Module        Asynchronous / Synchronous Serial Interface (ASC)
// @Filename      ASC.C
// @Project       prakt3.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C164CI-8E
//
// @Compiler      KEIL C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the
//                Asynchronous / Synchronous Serial Interface.
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

// USER CODE BEGIN (ASC_General,1)

// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (ASC_General,2)
#define NUM_LINES 4 //Numbers of Line
#define NUM_CAR 20 //Characters allowed in 1 Line
#define NUM_CTRL 4 //number of ctlr signs
#define CTRL_LINE 3 //shows to LINE Number

char globBuffer[NUM_CAR+NUM_CTRL]; //Allow 1 char more, 
char *curPointerToBuff=&globBuffer[0];//
char const *beginPointerToBuff = &globBuffer[0];//
char const *endPointerToBuff = &globBuffer[NUM_CAR+NUM_CTRL];
bit bdata bSendEnableFlag = 0;
bit bdata endFlg = 1;
// USER CODE END


//****************************************************************************
// @Function      void ASC_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the ASC component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the ASC
//                interrupts are to be released, and the priority of the 
//                released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void ASC_vInit(void)
{
  ///  8-bit data asynchronous operation
  ///  one stop bit
  ///  divide clock by reload value + constant
  ///  receiver disabled
  S0CON  = 0x0001;

  //   ASC baudrate reload register
  ///  baudrate =  9615,38 Baud
  S0BG   = 0x0040;

  ///  enable transmit interrupt
  ///  transmit interrupt priority level(ILVL) = 3
  ///  transmit interrupt group level (GLVL) = 1
  S0TIC = 0x004D;

  ////  transmit buffer interrupt is enabled but NO INTERRUPT
  ////  WILL BE GENERATED because the level and priority is 0
  S0TBIC = 0x0040;

  P3    |= 0x0400;    //  set P3.10 output latch (TXD0)
  DP3   |= 0x0400;    /// set P3.10 direction control (TXD0 output)


  // USER CODE BEGIN (ASC_Init,1)
  globBuffer[0]='\x1B';
  globBuffer[1]='O';
  globBuffer[2]=1;
  globBuffer[3]=1;

  // USER CODE END

  S0R    = 1;         //  enable baudrate generator
}


//****************************************************************************
// @Function      void ASC_viIsrTx(void) interrupt S0TINT
//
//----------------------------------------------------------------------------
// @Description   This is the transmit interrupt service routine for the ASC0.
//                It is called when the sending of data is terminated
//                (S0TIR is set).
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void ASC_viIsrTx(void) interrupt S0TINT
{
  // USER CODE BEGIN (ASC_IsrTx,1)
  if(bSendEnableFlag)
  {
    S0TBUF = *curPointerToBuff++;
	if(curPointerToBuff==endPointerToBuff)
		bSendEnableFlag=0;
  }	else 
  		endFlg = 1;
  // USER CODE END
}


//****************************************************************************
// @Function      void ASC_viIsrTxBuf(void) interrupt S0TBINT
//
//----------------------------------------------------------------------------
// @Description   This is the transmit buffer interrupt service routine for
//                the ASC0. It is called if the content of the TX-buffer has
//                been loaded into the TX-shift register.
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void ASC_viIsrTxBuf(void) interrupt S0TBINT
{
  // USER CODE BEGIN (ASC_IsrTxBuf,1)

  // USER CODE END
}




// USER CODE BEGIN (ASC_General,3)
void DoPrintZ (int iZnr, char *pBuf)
{
	char* curBuff = &globBuffer[NUM_CTRL];
	if(iZnr>NUM_LINES)
		return;
	while(!endFlg);
	endFlg = 0;
	bSendEnableFlag=0;
	globBuffer[CTRL_LINE]=(char)iZnr;
	curPointerToBuff=beginPointerToBuff;
	//send first byte
	S0TBUF = *curPointerToBuff++;
	//currently sending?
	while(*pBuf!='\0' && curBuff!=endPointerToBuff)
	{
		*curBuff=*pBuf++;
		*curBuff++;
		//Buffer will be filled faster then written to.
		bSendEnableFlag=1;
	}
	//fill with empty
	while(curBuff!=endPointerToBuff)
	{
	  *curBuff=' ';
	  curBuff++;
	}

}
void DoPrintWord (int iZnr,uword Word)
{
	char sendChar[5];
   	sendChar[3]=(char)(Word%10)+0x30;
	Word=Word/10;
	sendChar[2]=(char)(Word%10)+0x30;
	Word=Word/10;
   	sendChar[1]=(char)(Word%10)+0x30;
	Word=Word/10;
	sendChar[0]=(char)(Word%10)+0x30;
	sendChar[4]='\0';
	DoPrintZ(iZnr,sendChar);
}
void ClrScr(void)
{
	while(!endFlg);
	endFlg = 0;
   S0TBUF = '\xC';
   bSendEnableFlag=0;
}
bit isSending(void)
{
	return bSendEnableFlag;
}
// USER CODE END

