//****************************************************************************
// @Module        CC2
// @Filename      CC2.C
// @Project       prakt3.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C164CI-8E
//
// @Compiler      KEIL C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the CAPCOM 2
//                peripheral
//                
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

// USER CODE BEGIN (CC2_General,1)
#include "int.h"
// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (CC2_General,2)
	volatile bit cc19Last = 0;	//Tempature has been measured
	volatile bit cc19Da = 0;	//Tempature has been measured
	volatile bit cc18Da = 0;	
  uword idata uCC19Buffer[TEMP_BUFFERSIZE+1];
  uword idata uCC18Buffer[TEMP_BUFFERSIZE+1];	 
	 // volatile uword uTP[TEMP_BUFFERSIZE];
   // volatile uword uTD[TEMP_BUFFERSIZE];

// USER CODE END


//****************************************************************************
// @Function      void CC2_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the CAPCOM 2 component. It effects
//                all necessary configurations of the SFR, depending on the
//                selected operating mode. The configuration determines
//                whether the CAPCOM interrupts are to be released, and 
//                the priority of the released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void CC2_vInit(void)
{
  /// ---- Timer 7 Configuration -------------
  ///  timer 7 works in timer mode
  ///  prescaler factor is 8
  ///  timer 7 run bit is reset

  /// ---- Timer 8 Configuration -------------
  ///  timer 8 works in timer mode
  ///  prescaler factor is 8

  T78CON = 0x0000;
  T7     = 0x0000;    // load timer 7 register
  T8     = 0x0000;    // load timer 8 register
  T7REL  = 0x0000;    // load timer 7 reload register
  T8REL  = 0x0000;    // load timer 8 reload register

  /// P8.2 is used as input for CAPCOM channel 18
  /// P8.3 is used as input for CAPCOM channel 19

  /// ---- Capture Compare Channel 16 -------------
  ///  disable capture compare channel 16

  /// ---- Capture Compare Channel 17 -------------
  ///  disable capture compare channel 17

  /// ---- Capture Compare Channel 18 -------------
  ///  capture on positive transition (rising edge) at pin CC18IO
  ///  CC18 allocated to timer T8

  /// ---- Capture Compare Channel 19 -------------
  ///  capture on negative transition (falling edge) at pin CC19IO
  ///  CC19 allocated to timer T8

  CCM4  = 0xA900;
  CC18  = 0x0000;  // load CC18 register
  CC19  = 0x0000;  // load CC19 register

  ///  enable CC18 interrupt
  ///  CC18 interrupt priority level(ILVL) = 14
  ///  CC18 interrupt group level (GLVL) = 3
  CC18IC = 0x007B;

  ///  use PEC channel 3 for CC18 interrupt
  ///  - count = 51
  ///  - word transfer
  ///  - increment destination pointer
  PECC3 = 0x0233;

  SRCP3 = _sof_(&CC18);
  /// User defined destination pointer is selected for PECC Channel 3

  ///  enable CC19 interrupt
  ///  CC19 interrupt priority level(ILVL) = 14
  ///  CC19 interrupt group level (GLVL) = 2
  CC19IC = 0x007A;

  ///  use PEC channel 2 for CC19 interrupt
  ///  - count = 51
  ///  - word transfer
  ///  - increment destination pointer
  PECC2 = 0x0233;

  SRCP2 = _sof_(&CC19);
  /// User defined destination pointer is selected for PECC Channel 2


  /// ---- Capture Compare Channel 24 -------------
  ///  disable capture compare channel 24

  /// ---- Capture Compare Channel 25 -------------
  ///  disable capture compare channel 25

  /// ---- Capture Compare Channel 26 -------------
  ///  disable capture compare channel 26

  /// ---- Capture Compare Channel 27 -------------
  ///  disable capture compare channel 27

  /// timer 8 is running
  T78CON |= 0x4000;


  // USER CODE BEGIN (CC2_Init,1)
// DO NOT FORGET TO SET THE DESTINATION-POINTER FOR PECC CHANNEL 2
// DO NOT FORGET TO SET THE DESTINATION-POINTER FOR PECC CHANNEL 3
	 CC18IE=0;
   CC19IE=0; //DAVE workaround
  // USER CODE END

}


//****************************************************************************
// @Function      void CC2_viIsrCC18(void) interrupt CC18INT
//
//----------------------------------------------------------------------------
// @Description   This is the interrupt service routine for the capture/
//                compare register CC18. If the content of the corresponding 
//                compare timer (configurable) equals the content of the
//                capture/compare register CC18 or if a capture event
//                occurs at the associated port pin, the interrupt request 
//                flag is set and an interrupt or PEC transfer is triggered
//                (only if enabled).
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void CC2_viIsrCC18(void) interrupt CC18INT
{
  // USER CODE BEGIN (CC2_IsrCC18,0)
		CC18IE=0;
		cc19Last=0;
		cc18Da = 1;
	
  // USER CODE END
}


//****************************************************************************
// @Function      void CC2_viIsrCC19(void) interrupt CC19INT
//
//----------------------------------------------------------------------------
// @Description   This is the interrupt service routine for the capture/
//                compare register CC19. If the content of the corresponding 
//                compare timer (configurable) equals the content of the
//                capture/compare register CC19 or if a capture event
//                occurs at the associated port pin, the interrupt request 
//                flag is set and an interrupt or PEC transfer is triggered
//                (only if enabled).
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void CC2_viIsrCC19(void) interrupt CC19INT
{
  // USER CODE BEGIN (CC2_IsrCC19,0)
	CC19IE=0;//When already running, no new intterupt will be started
	cc19Last=1;
	cc19Da = 1;
  // USER CODE END
}



// USER CODE BEGIN (CC2_General,3)
 // USER CODE BEGIN (CC2Header,1)
void StartTemp() 
{	
	INT_vSetPecCount(2,51);
	INT_vSetPecCount(3,51);	
	INT_vSetPecDesP(2,uCC19Buffer); 
	INT_vSetPecDesP(3,uCC18Buffer); 

	//test work around...
	CC18IR = CC19IR = 0;
	CC18IE=1;
	CC19IE=1;//When already running, no new intterupt will be started
}
bit bTempDa()
{
	bit bRetBit = 0;
	if(cc18Da && cc19Da)
	{
		cc18Da = cc19Da = 0;
		bRetBit=1;
	}
	return bRetBit;
}

float fGetTemp()
{
	uword uTP;
  uword uTD;
	uword idata *pCC19Buffer;
  uword idata *pCC18Buffer;	 
	int i=0;
	float fTemp = 0;
	//Mitteln von uTP und uTD
	pCC19Buffer=&uCC19Buffer[TEMP_BUFFERSIZE];
	pCC18Buffer=&uCC18Buffer[TEMP_BUFFERSIZE];
	if(!cc19Last) //cc19 was not the last interrupt, change the "last" cc18 buffer to be synchronized
		pCC18Buffer--;
	for(i=0;i<TEMP_BUFFERSIZE;i++)
	{
		uTD=*pCC19Buffer-*pCC18Buffer;
		uTP=*pCC19Buffer-*(pCC19Buffer-1);
		fTemp+=(1.0/0.0047)*(float)uTD/(float)uTP-(0.32/0.0047);
		pCC19Buffer--;
		pCC18Buffer--;
	}
	fTemp=fTemp/TEMP_BUFFERSIZE;
	return fTemp;
}
// USER CODE END


