//****************************************************************************
// @Module        General Purpose Timer Unit 1
// @Filename      GT1.C
// @Project       prakt3.dav
//----------------------------------------------------------------------------
// @Controller    Infineon C164CI-8E
//
// @Compiler      KEIL C166
//
// @Codegenerator DAvE 2-0-0
//
// @Description   This file contains all functions that use the GPT1 unit.
//                
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************


//****************************************************************************
// @Project Includes
//****************************************************************************

#include "MAIN.H"

// USER CODE BEGIN (GT1_General,1)
#include "IO.H"
#include "ADC.H"
// USER CODE END


//***************************************************************************
// @Global Variables
//***************************************************************************

// USER CODE BEGIN (GT1_General,2)
unsigned char u8gKeyStatus=0xF0;
bit bdata bFlagKey=0;
ADCHANNELS gADChannels[3];
unsigned char gCurChannel=0;
// USER CODE END


//****************************************************************************
// @Function      void GT1_vInit(void)
//
//----------------------------------------------------------------------------
// @Description   This function initializes the GPT1 component. It effects all
//                necessary configurations of the SFR, depending on the selected
//                operating mode. The configuration determines whether the GPT1
//                interrupts are to be released, and the priority of the 
//                released interrupt.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void GT1_vInit(void)
{
  /// ------------ Timer 3 Control Register ----------
  ///  timer 3 works in timer mode
  ///  prescaler factor is 8
  ///  up/down control bit is set
  ///  external up/down control is disabled
  T3CON = 0x0080;
  T3    = 0x09C3;  //  load timer 3 register

  ///  enable timer 3 interrupt
  ///  timer 3 interrupt priority level(ILVL) = 5
  ///  timer 3 interrupt group level (GLVL) = 3
  T3IC = 0x0057;

  /// ---------- Timer 2 Control Register ----------
  ///  timer 2 works in timer mode
  ///  prescaler factor is 8
  ///  up/down control bit is reset 
  ///  external up/down control is disabled
  T2CON = 0x0000;
  T2    = 0x0000;  //  load timer 2 register

  ///  enable timer 2 interrupt
  ///  timer 2 interrupt priority level(ILVL) = 4
  ///  timer 2 interrupt group level (GLVL) = 2
  T2IC = 0x0052;

  /// ---------- Timer 4 Control Register ----------
  ///  timer 4 works in reload mode 
  ///  any transition (rising and falling edge) of output toggle latch T3OTL
  T4CON = 0x0027;
  T4    = 0x09C3;  //  load timer 4 register



  // USER CODE BEGIN (GT1_Init,1)
	gADChannels[0].curBuffer = gADChannels[0].buffer;
	gADChannels[1].curBuffer = gADChannels[1].buffer;
	gADChannels[2].curBuffer = gADChannels[2].buffer;
	ADC_vConfConv(FIXED,AN0);
	ADC_vStartConv();
  // USER CODE END


  T2R = 1;         //   set timer 2 run bit 
  T3R = 1;         //   set timer 3 run bit 
}


//****************************************************************************
// @Function      void GT1_viIsrTmr3(void) interrupt T3INT
//
//----------------------------------------------------------------------------
// @Description   This is the interrupt service routine for the GPT1 timer 3.
//                It is called up in the case of over or underflow of the 
//                timer 3 register.
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void GT1_viIsrTmr3(void) interrupt T3INT
{
  // USER CODE BEGIN (GT1_IsrTmr3,1)
	const unsigned char nextChannel[3] = {AN1,AN2,AN0};
	static unsigned char curChannel=AN0;
	uword lastValue;
	//save last value

	lastValue=(ADC_uwReadConv()&0x03FF);
	//curBuffer is last BUFFer
	gADChannels[curChannel].sum=gADChannels[curChannel].sum+lastValue-*(gADChannels[curChannel].curBuffer);
   	*(gADChannels[curChannel].curBuffer)=lastValue;
	if(gADChannels[curChannel].curBuffer==&(gADChannels[curChannel].buffer[19]))
		gADChannels[curChannel].curBuffer=&(gADChannels[curChannel].buffer[0]);
	else 
		gADChannels[curChannel].curBuffer++;
		//change channel
	curChannel=nextChannel[curChannel];	
	//config confersion and start
	ADC_vConfConv(FIXED,curChannel);
	ADC_vStartConv();
  // USER CODE END
}


//****************************************************************************
// @Function      void GT1_viIsrTmr2(void) interrupt T2INT
//
//----------------------------------------------------------------------------
// @Description   This is the interrupt service routine for the GPT1 timer 2.
//                It is called up when the timer 2 register over or under-
//                flows or if timer 3 is reloaded with the content of timer 2
//                (external signal or T3 over/underflow) or if an external
//                capture event arrives.
//                
//                Please note that you have to add application specific
//                code to this function.
//
//----------------------------------------------------------------------------
// @Returnvalue   none
//
//----------------------------------------------------------------------------
// @Parameters    none
//
//----------------------------------------------------------------------------
// @Date          27.05.2013 08:39:19
//
//****************************************************************************

void GT1_viIsrTmr2(void) interrupt T2INT
{
  // USER CODE BEGIN (GT1_IsrTmr2,1)
	static unsigned char  u8lastPressedKey = 0xF0;
	static unsigned char u8keyCount = 0x00;
	//same key pressed
	unsigned char u8curKeyPressed=(char)(P1H);//0x00F0
	//Just count if key is different then the global key status
	if((u8gKeyStatus!=u8curKeyPressed)&&//only if the current key pressed is different then the last pressed  valid key
	(u8curKeyPressed==u8lastPressedKey))//only if currently pressed Key is the same  as the last time (not global) pressed key
	{
		u8keyCount++;//increase number of times key pressed
		if(u8keyCount==2)//Key has been pressed 2 times an
		{
			u8gKeyStatus=u8curKeyPressed;
			u8keyCount=0;
			if(u8curKeyPressed!=0xF0)//only set flag when a key is really pressed	
				bFlagKey=1;	
		}
	}
   	else
		 u8lastPressedKey=u8curKeyPressed;
  // USER CODE END
}




// USER CODE BEGIN (GT1_General,3)
bit KeyDown(void)
{
	bit retBit=bFlagKey;
	if(retBit)
		bFlagKey=0;
	return retBit;
}

char GetKey(void)
{
	char cretChar='0';
	//Keys are pressed with low pegel => invert and we don't care about pin 0-3
	switch((~u8gKeyStatus)&0x00F0)
	{
		case (1<<4)://P1H.4
			cretChar='1';
			break;
		case (1<<5)://P1H.5	  
			cretChar='2';
			break;
		case (1<<6)://P1H.6
			cretChar='3';
			break;
		case (1<<7)://P1H.7
			cretChar='4';
			break;
		default:
			cretChar='0';
			break;
	}
	return cretChar;																					
}

uword fGibADMittel(unsigned char channel)
{
	if(channel>2)
		return 0;
	return (gADChannels[channel].sum/20);
}

uword fGibGewicht()
{
  uword retValue=(gADChannels[0].sum/20); 
  retValue+=(gADChannels[1].sum/20);
  retValue+=(gADChannels[2].sum/20);
  return retValue;
}
// USER CODE END

